@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2023 - 2025 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -538,7 +538,7 @@ void Client::diagnostic(const WorkspaceDiagnosticParams &params)
 
 void Client::selectLspServer(const newlsp::ProjectKey &key)
 {
-    if (d->proKey == key)
+    if (d->proKey == key && d->isClientValid)
         return;
 
     d->proKey = key;
@@ -1342,6 +1342,7 @@ bool ClientPrivate::calledResult(const QJsonObject &jsonObj)
         || !jsonObj.contains(K_RESULT))
         return false;
 
+    isClientValid = true;
     bool any = false;
     any |= initResult(jsonObj);
     any |= openResult(jsonObj);
@@ -1401,6 +1402,11 @@ lsp::SemanticTokensProvider Client::initSecTokensProvider()
     return d->secTokensProvider;
 }
 
+bool Client::isValid() const
+{
+    return d->isClientValid;
+}
+
 ClientPrivate::ClientPrivate(Client *const q)
     : newlsp::StdoutJsonRpcParser(), q(q), requestIndex(0), requestSave({}), semanticTokenResultId(0), fileVersion({}), secTokensProvider({}), proKey({})
 {
